@@ -1,11 +1,11 @@
 #ifndef __LBFGSB_H__
 #define __LBFGSB_H__
 
-extern long int lbfgsb3_(int *n, int *m, double *x, double *l, double *u,
-			 int *nbd, double *f, double *g, double *factr,
-			 double *pgtol, double *wa, int *iwa, int *itask,
-			 int *iprint, int *icsave, int *lsave, int *isave,
-			 double *dsave);
+extern void lbfgsb3_(int *n, int *m, double *x, double *l, double *u,
+		     int *nbd, double *f, double *g, double *factr,
+		     double *pgtol, double *wa, int *iwa, int *itask,
+		     int *iprint, int *icsave, int *lsave, int *isave,
+		     double *dsave);
 typedef double (* lbfgsb_fmin)(int, double*, void*);
 typedef void (* lbfgsb_fgrad)(int, double*, double *, void *);
 
